@@ -1,10 +1,11 @@
 # rkeops >= 2.0 features a python dependency, which, at this time,
 # requires users to manage both a Python install and R install
 if ( rlang::is_installed("rkeops") ) {
-  two_debian_catch <- base::.make_numeric_version("2.0",TRUE,.standard_regexps()$valid_numeric_version)
+  two_debian_catch <- pkg_vers_number("2.0")
   vers_match   <- tryCatch(utils::packageVersion("rkeops") >= two_debian_catch,
                            error = function(e) FALSE)
-  if (vers_match && rlang::is_installed("reticulate")) {
+  not_on_cran <-  !(!interactive() && !isTRUE(as.logical(Sys.getenv("NOT_CRAN", "false"))))
+  if (not_on_cran && vers_match && rlang::is_installed("reticulate")) {
     if (is.character(find.package("reticulate"))) {
       rkeops_pyenv <- "rkeops_test_asdf"
       # setup.mess <- reticulate::py_capture_output({
